# Copyright 2024-2025 MOSTLY AI
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from collections.abc import Callable
from pathlib import Path

from mostlyai.sdk._local.execution.migration import migrate_workspace


def execute_step_encode_training_data(
    *,
    workspace_dir: Path,
    update_progress: Callable,
):
    # import ENGINE here to avoid pre-mature loading of large ENGINE dependencies
    from mostlyai import engine

    # ensure backward compatibility
    migrate_workspace(workspace_dir)

    # call ENCODE
    engine.encode(
        workspace_dir=workspace_dir,
        update_progress=update_progress,
    )
